# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/restaurant/eatery/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Restaurant\\Eatery\\": "packages/restaurant/eatery/src",
            "Restaurant\\Eatery\\Seeders\\": "packages/restaurant/eatery/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Restaurant\Eatery\Providers\EateryServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Eatery'  => Restaurant\Eatery\Facades\Eatery::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Restaurant\\Eatery\\Seeders\\EateryTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Restaurant\Eatery\Providers\EateryServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Restaurant\Eatery\Providers\EateryServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Restaurant\Eatery\Providers\EateryServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/eatery/{modulename}

**User**

    http://path-to-route-folder/user/eatery/{modulename}

**Public**

    http://path-to-route-folder/eateries


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/eatery/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/eatery/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/eatery/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/eatery/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/eatery/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/eatery/{modulename}/{slug}
    METHOD: GET