<?php

namespace Restaurant\Eatery\Providers;

use Illuminate\Support\ServiceProvider;
use Restaurant\Eatery\Eateries;

class EateryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'eatery');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'eatery');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Restaurant\Eatery\Providers\AuthServiceProvider::class);
        $this->app->register(\Restaurant\Eatery\Providers\RouteServiceProvider::class);
        // $this->app->register(\Restaurant\Eatery\Providers\EventServiceProvider::class);
        // $this->app->register(\Restaurant\Eatery\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('restaurant.eatery', function($app)
        {
            return $this->app->make(Eateries::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Eatery to repository
        $this->app->bind(
            'Restaurant\Eatery\Interfaces\EateryRepositoryInterface',
            \Restaurant\Eatery\Repositories\Eloquent\EateryRepository::class
        );
    }


    /**
     * Merges user's and eatery's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'restaurant.eatery'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Restaurant\Eatery\Commands\Eatery::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['restaurant.eatery'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('restaurant/eatery.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/eatery')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/eatery')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
